Label single select questions
singsel_label.RdLabel single select questions
Arguments
- surveydata
a tibble with survey data as processed by
scto_responses- thefields
a tibble with survey fields as processed by
read_questions

singsel_label.RdLabel single select questions
a tibble with survey data as processed by scto_responses
a tibble with survey fields as processed by read_questions